# Curl_Navi
> Class and function for curriculum learning


This file will become your README and also the index of your documentation.

## Install

`pip3 install curl_navi`

## How to use

Take a look at Evaluation function

`cd ~/curl_navi`
